summaryrefslogtreecommitdiff
blob: 4d3dbaddc793346a1d45ae2ffb9cb3e67184f628 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
diff -ur ZoneMinder-1.24.2.orig/src/zm_image.cpp ZoneMinder-1.24.2/src/zm_image.cpp
--- ZoneMinder-1.24.2.orig/src/zm_image.cpp	2009-05-25 21:04:00.000000000 +0300
+++ ZoneMinder-1.24.2/src/zm_image.cpp	2010-02-22 17:43:14.000000000 +0200
@@ -461,7 +461,7 @@
 		return( false );
 	}
 
-	jpeg_mem_src( cinfo, inbuffer, inbuffer_size );
+	zm_jpeg_mem_src( cinfo, inbuffer, inbuffer_size );
 
 	jpeg_read_header( cinfo, TRUE );
 
@@ -523,7 +523,7 @@
 		jpeg_create_compress( cinfo );
 	}
 
-	jpeg_mem_dest( cinfo, outbuffer, outbuffer_size );
+	zm_jpeg_mem_dest( cinfo, outbuffer, outbuffer_size );
 
 	cinfo->image_width = width; 	/* image width and height, in pixels */
 	cinfo->image_height = height;
diff -ur ZoneMinder-1.24.2.orig/src/zm_jpeg.h ZoneMinder-1.24.2/src/zm_jpeg.h
--- ZoneMinder-1.24.2.orig/src/zm_jpeg.h	2009-03-20 14:07:00.000000000 +0200
+++ ZoneMinder-1.24.2/src/zm_jpeg.h	2010-02-22 17:43:14.000000000 +0200
@@ -36,5 +36,5 @@
 void zm_jpeg_emit_message( j_common_ptr cinfo, int msg_level );
 
 // Prototypes for memory compress/decompression object */
-void jpeg_mem_src(j_decompress_ptr cinfo, const JOCTET *inbuffer, int inbuffer_size );
-void jpeg_mem_dest(j_compress_ptr cinfo, JOCTET *outbuffer, int *outbuffer_size );
+void zm_jpeg_mem_src(j_decompress_ptr cinfo, const JOCTET *inbuffer, int inbuffer_size );
+void zm_jpeg_mem_dest(j_compress_ptr cinfo, JOCTET *outbuffer, int *outbuffer_size );
diff -ur ZoneMinder-1.24.2.orig/src/zm_jpeg.c ZoneMinder-1.24.2/src/zm_jpeg.c
--- ZoneMinder-1.24.2.orig/src/zm_jpeg.c	2009-03-20 14:07:00.000000000 +0200
+++ ZoneMinder-1.24.2/src/zm_jpeg.c	2010-02-22 17:43:14.000000000 +0200
@@ -173,7 +173,7 @@
  * for closing it after finishing compression.
  */
 
-void jpeg_mem_dest (j_compress_ptr cinfo, JOCTET *outbuffer, int *outbuffer_size )
+void zm_jpeg_mem_dest (j_compress_ptr cinfo, JOCTET *outbuffer, int *outbuffer_size )
 {
     mem_dest_ptr dest;
 
@@ -350,12 +350,12 @@
  * for closing it after finishing decompression.
  */
 
-void jpeg_mem_src( j_decompress_ptr cinfo, const JOCTET *inbuffer, int inbuffer_size )
+void zm_jpeg_mem_src( j_decompress_ptr cinfo, const JOCTET *inbuffer, int inbuffer_size )
 {
     mem_src_ptr src;
 
     /* The source object and input buffer are made permanent so that a series
      * of JPEG images can be read from the same file by calling jpeg_mem_src
      * only before the first one.  (If we discarded the buffer at the end of
      * one image, we'd likely lose the start of the next one.)
      * This makes it unsafe to use this manager and a different source
@@ -350,12 +350,12 @@
 
     /* The source object and input buffer are made permanent so that a series
-     * of JPEG images can be read from the same file by calling jpeg_mem_src
+     * of JPEG images can be read from the same file by calling zm_jpeg_mem_src
      * only before the first one.  (If we discarded the buffer at the end of
      * one image, we'd likely lose the start of the next one.)